EbccCodecError

Enum EbccCodecError 

pub enum EbccCodecError {
    UnsupportedDtype(AnyArrayDType),
    HeaderEncodeFailed {
        source: EbccHeaderError,
    },
    InsufficientDimensions {
        shape: Vec<usize>,
    },
    EbccEncodeFailed {
        source: EbccCodingError,
    },
    SliceEncodeFailed {
        source: EbccSliceError,
    },
    EncodedDataNotBytes {
        dtype: AnyArrayDType,
    },
    EncodedDataNotOneDimensional {
        shape: Vec<usize>,
    },
    HeaderDecodeFailed {
        source: EbccHeaderError,
    },
    DecodeIntoShapeMismatch {
        decoded: Vec<usize>,
        array: Vec<usize>,
    },
    SliceDecodeFailed {
        source: EbccSliceError,
    },
    DecodeTooManySlices,
    EbccDecodeFailed {
        source: EbccCodingError,
    },
}
Errors that may occur when applying the EbccCodec.

Variants



UnsupportedDtype(AnyArrayDType)

EbccCodec does not support the dtype



HeaderEncodeFailed

EbccCodec failed to encode the header

Fields

source: EbccHeaderError

Opaque source error



InsufficientDimensions

EbccCodec can only encode >2D data where the last two dimensions must be at least 32x32 but received an array with an insufficient shape

Fields

shape: Vec<usize>

The unexpected shape of the array



EbccEncodeFailed

EbccCodec failed to encode the data

Fields

source: EbccCodingError

Opaque source error



SliceEncodeFailed

EbccCodec failed to encode a 3D slice

Fields

source: EbccSliceError

Opaque source error



EncodedDataNotBytes

EbccCodec can only decode one-dimensional byte arrays but received an array of a different dtype

Fields

dtype: AnyArrayDType

The unexpected dtype of the encoded array



EncodedDataNotOneDimensional

EbccCodec can only decode one-dimensional byte arrays but received an array of a different shape

Fields

shape: Vec<usize>

The unexpected shape of the encoded array



HeaderDecodeFailed

EbccCodec failed to decode the header

Fields

source: EbccHeaderError

Opaque source error



DecodeIntoShapeMismatch

EbccCodec cannot decode into an array with a mismatching shape

Fields

decoded: Vec<usize>

The shape of the decoded data

array: Vec<usize>

The mismatching shape of the array to decode into



SliceDecodeFailed

EbccCodec failed to decode a 3D slice

Fields

source: EbccSliceError

Opaque source error



DecodeTooManySlices

EbccCodec failed to decode from an excessive number of slices



EbccDecodeFailed

EbccCodec failed to decode the data

Fields

source: EbccCodingError

Opaque source error