pub fn decompress_into<S: DataMut<Elem = f32>, D: Dimension>(
encoded: &[u8],
decoded: ArrayBase<S, D>,
) -> Result<(), EbccCodecError>Expand description
Decompress the encoded data into the decoded array using EBCC.
Errors
Errors with
EbccCodecError::HeaderDecodeFailedif decoding the header failedEbccCodecError::DecodeIntoShapeMismatchis thedecodedarray shape does not match the shape of the decoded dataEbccCodecError::SliceDecodeFailedif decoding a 3D slice failedEbccCodecError::EbccDecodeFailedif decoding with EBCC failedEbccCodecError::DecodeTooManySlicesif the encoded data contains too many slices